@@ -3,8 +3,9 @@ find . \( -type f -o -type l \) \
    -not -name 'Makefile.old' \
    -not -path './makedeb/*' \
    -not -path "./debian/*" \
+   -not -path "./todo/*" \
+   -not -path "./App-RecordStream*.tar.gz" \
    -not -path "./deb-dist/*" \
-   -not -path "./doc/recs-*" \
    -not -path "./blib/*" \
    -not -path './.git/*' \
    -not -path ./Makefile \
